@@ -18,6 +18,7 @@ import os
 
 import click
 
+from polyaxon.cli.dashboard import get_dashboard, get_dashboard_url
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.managers.deploy import DeployManager
 from polyaxon.utils.formatting import Printer
@@ -58,6 +59,9 @@ def admin():
     type=click.Path(exists=True),
     help="The polyaxon deployment config file(s) to check.",
 )
+@click.option(
+    "-t", "--deployment-type", help="Deployment type.",
+)
 @click.option(
     "--manager-path",
     type=click.Path(exists=True),
@@ -75,11 +79,15 @@ def admin():
     default=False,
     help="Dry run the configuration and generate a debuggable output.",
 )
-def deploy(config_file, manager_path, check, dry_run):
+def deploy(config_file, deployment_type, manager_path, check, dry_run):
     """Deploy polyaxon."""
     config = read_deployment_config(config_file)
     manager = DeployManager(
-        config=config, filepath=config_file, manager_path=manager_path, dry_run=dry_run
+        config=config,
+        filepath=config_file,
+        deployment_type=deployment_type,
+        manager_path=manager_path,
+        dry_run=dry_run,
     )
     exception = None
     if config:
@@ -113,6 +121,9 @@ def deploy(config_file, manager_path, check, dry_run):
     type=click.Path(exists=True),
     help="The polyaxon deployment config file(s) to check.",
 )
+@click.option(
+    "-t", "--deployment-type", help="Deployment type.",
+)
 @click.option(
     "--manager-path",
     type=click.Path(exists=True),
@@ -130,11 +141,15 @@ def deploy(config_file, manager_path, check, dry_run):
     default=False,
     help="Dry run the configuration and generate a debuggable output.",
 )
-def upgrade(config_file, manager_path, check, dry_run):
+def upgrade(config_file, deployment_type, manager_path, check, dry_run):
     """Upgrade a Polyaxon deployment."""
     config = read_deployment_config(config_file)
     manager = DeployManager(
-        config=config, filepath=config_file, manager_path=manager_path, dry_run=dry_run
+        config=config,
+        filepath=config_file,
+        deployment_type=deployment_type,
+        manager_path=manager_path,
+        dry_run=dry_run,
     )
     exception = None
     if config:
@@ -190,3 +205,20 @@ def teardown(config_file, manager_path):
 
     if exception:
         Printer.print_error("Error message: {}.".format(exception))
+
+
+@admin.command()
+@click.option(
+    "--yes",
+    "-y",
+    is_flag=True,
+    default=False,
+    help="Automatic yes to prompts. "
+    'Assume "yes" as answer to all prompts and run non-interactively.',
+)
+@click.option(
+    "--url", is_flag=True, default=False, help="Print the url of the dashboard."
+)
+def dashboard(yes, url):
+    """Open dashboard in browser."""
+    get_dashboard(dashboard_url=get_dashboard_url(base="_admin"), url_only=url, yes=yes)
