@@ -24,7 +24,6 @@ from polyaxon.cli.check import check_polyaxonfile
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.config_reader.spec import ConfigSpec
 from polyaxon.exceptions import PolyaxonBuildException, PolyaxonSchemaError
-from polyaxon.logger import clean_outputs
 from polyaxon.polyaxonfile.specs import CompiledOperationSpecification
 from polyaxon.schemas.fields.docker_image import validate_image
 from polyaxon.schemas.types import V1DockerfileType
@@ -33,7 +32,6 @@ from polyaxon.utils.path_utils import copy_file
 
 
 @click.group()
-@clean_outputs
 def docker():
     pass
 
@@ -51,16 +49,12 @@ def docker():
     "-pm", "--python-module", type=str, help="The python module to run.",
 )
 @click.option(
-    "--build_context",
-    "--build-context",
-    help="The build context config to generate the dockerfile from.",
+    "--build-context", help="The build context config to generate the dockerfile from.",
 )
 @click.option(
     "-dest", "--destination", help="The destination where to generate the build."
 )
-@click.option(
-    "--copy-path", "--copy_path", help="Copy generated files to a specific path."
-)
+@click.option("--copy-path", help="Copy generated files to a specific path.")
 @click.option(
     "--params",
     "-P",
@@ -68,11 +62,19 @@ def docker():
     multiple=True,
     help="A parameter to override the default params of the run, form -P name=value.",
 )
-@clean_outputs
+@click.option(
+    "--track",
+    is_flag=True,
+    default=False,
+    help="Flag to track or not the file content.",
+)
 def generate(
-    polyaxonfile, python_module, build_context, destination, copy_path, params
+    polyaxonfile, python_module, build_context, destination, copy_path, params, track
 ):
     """Generate a dockerfile given the polyaxonfile."""
+    from polyaxon.init.dockerfile import create_dockerfile_lineage
+    from polyaxon.utils.hashing import hash_value
+
     if all([polyaxonfile, build_context]):
         Printer.print_error(
             "Only a polyaxonfile or a build context option is required."
@@ -99,7 +101,7 @@ def generate(
         try:
             compiled_operation = specification.compile_operation()
             compiled_operation.apply_params(params=specification.config.params)
-            compiled_operation = CompiledOperationSpecification.apply_context(
+            compiled_operation = CompiledOperationSpecification.apply_operation_contexts(
                 compiled_operation
             )
         except PolyaxonSchemaError:
@@ -120,8 +122,12 @@ def generate(
             "Dockerfile was generated, path: `{}`".format(generator.dockerfile_path)
         )
 
+        dockerfile_path = generator.dockerfile_path
         if copy_path:
-            copy_file(generator.dockerfile_path, copy_path)
+            dockerfile_path = copy_file(dockerfile_path, copy_path)
+        if track:
+            hash_content = hash_value(init_dockerfile.to_dict())
+            create_dockerfile_lineage(dockerfile_path, summary={"hash": hash_content})
 
 
 @docker.command()
@@ -143,14 +149,12 @@ def generate(
     help="To force rebuild the image.",
 )
 @click.option(
-    "--max_retries",
     "--max-retries",
     type=int,
     default=3,
     help="Number of times to retry the build process.",
 )
 @click.option(
-    "--sleep_interval",
     "--sleep-interval",
     type=int,
     default=2,
@@ -163,7 +167,6 @@ def generate(
     show_default=False,
     help="To force rebuild the image.",
 )
-@clean_outputs
 def build(context, destination, nocache, max_retries, sleep_interval, reraise):
     """Build a dockerfile, this command required Docker to be installed."""
     from polyaxon.builds.builder import build
@@ -200,7 +203,6 @@ def build(context, destination, nocache, max_retries, sleep_interval, reraise):
     help="Number of times to retry the build process.",
 )
 @click.option(
-    "--sleep_interval",
     "--sleep-interval",
     type=int,
     default=2,
@@ -213,7 +215,6 @@ def build(context, destination, nocache, max_retries, sleep_interval, reraise):
     show_default=False,
     help="To force rebuild the image.",
 )
-@clean_outputs
 def push(destination, max_retries, sleep_interval, reraise):
     """Push an image, this command required Docker to be installed."""
     from polyaxon.builds.builder import push
@@ -257,7 +258,6 @@ def push(destination, max_retries, sleep_interval, reraise):
     help="Number of times to retry the build process.",
 )
 @click.option(
-    "--sleep_interval",
     "--sleep-interval",
     type=int,
     default=2,
@@ -270,7 +270,6 @@ def push(destination, max_retries, sleep_interval, reraise):
     show_default=False,
     help="To force rebuild the image.",
 )
-@clean_outputs
 def build_and_push(context, destination, nocache, max_retries, sleep_interval, reraise):
     """
     Build a dockerfile and push it to the provided registry,
