@@ -22,9 +22,19 @@ def handle_cli_error(e, message=None, sys_exit: bool = False):
     if message:
         Printer.print_error(message)
     if hasattr(e, "status"):
-        Printer.print_error("Error message: {}.".format(e))
+        if e.status not in [404, 401, 403]:
+            Printer.print_error("Error message: {}.".format(e))
         Printer.print_error(
             HTTP_ERROR_MESSAGES_MAPPING.get(e.status), sys_exit=sys_exit
         )
+    elif hasattr(e, "message"):  # Handling of HTML errors
+        if "404" in e.message:
+            Printer.print_error(HTTP_ERROR_MESSAGES_MAPPING.get(404), sys_exit=sys_exit)
+        elif "401" in e.message:
+            Printer.print_error(HTTP_ERROR_MESSAGES_MAPPING.get(401), sys_exit=sys_exit)
+        elif "403" in e.message:
+            Printer.print_error(HTTP_ERROR_MESSAGES_MAPPING.get(403), sys_exit=sys_exit)
+        else:
+            Printer.print_error("Error message: {}.".format(e), sys_exit=sys_exit)
     else:
         Printer.print_error("Error message: {}.".format(e), sys_exit=sys_exit)
