@@ -24,7 +24,6 @@ from polyaxon import settings
 from polyaxon.cli.executor import docker_run, k8s_run, platform_run
 from polyaxon.env_vars.getters import get_project_or_local
 from polyaxon.exceptions import PolyaxonSchemaError
-from polyaxon.logger import clean_outputs
 from polyaxon.polyaxonfile import (
     CompiledOperationSpecification,
     OperationSpecification,
@@ -65,13 +64,6 @@ from polyaxon.utils.validation import validate_tags
 )
 @click.option("--tags", type=str, help="Tags of this run, comma separated values.")
 @click.option("--description", type=str, help="The description to give to this run.")
-@click.option(
-    "--upload",
-    "-u",
-    is_flag=True,
-    default=False,
-    help="To upload the repo before running.",
-)
 @click.option(
     "--log",
     "-l",
@@ -92,7 +84,6 @@ from polyaxon.utils.validation import validate_tags
     default=False,
     help="To start the run locally, with `docker` environment as default.",
 )
-@click.option("--conda_env", type=str, help="To start a local run with `conda`.")
 @click.option(
     "--params",
     "-P",
@@ -101,7 +92,14 @@ from polyaxon.utils.validation import validate_tags
     help="A parameter to override the default params of the run, form -P name=value.",
 )
 @click.option("--profile", type=str, help="Name of the profile to use for this run.")
-@click.option("--queue", type=str, help="Name of the queue to use for this run.")
+@click.option(
+    "--queue",
+    "-q",
+    type=str,
+    help="Name of the queue to use for this run. "
+    "If the name is not namespaced by the agent name the default agent is used: "
+    "queue-name or agent-name/queue-name",
+)
 @click.option(
     "--nocache",
     is_flag=True,
@@ -109,7 +107,6 @@ from polyaxon.utils.validation import validate_tags
     help="Disable cache check before starting this operation.",
 )
 @click.pass_context
-@clean_outputs
 def run(
     ctx,
     project,
@@ -120,11 +117,9 @@ def run(
     name,
     tags,
     description,
-    upload,
     log,
     watch,
     local,
-    conda_env,
     params,
     profile,
     queue,
@@ -137,15 +132,10 @@ def run(
     \b
     $ polyaxon run -f file -f file_override ...
 
-    Upload before running
-
-    \b
-    $ polyaxon run -f file -u
-
     Run and set description and tags for this run
 
     \b
-    $ polyaxon run -f file -u --description="Description of the current run" --tags="foo, bar, moo"
+    $ polyaxon run -f file --description="Description of the current run" --tags="foo, bar, moo"
 
     Run and set a unique name for this run
 
@@ -191,7 +181,7 @@ def run(
     if local:
         try:
             compiled_operation = OperationSpecification.compile_operation(op_spec)
-            compiled_operation = CompiledOperationSpecification.apply_context(
+            compiled_operation = CompiledOperationSpecification.apply_operation_contexts(
                 compiled_operation
             )
         except (PolyaxonSchemaError, ValidationError):
@@ -219,9 +209,7 @@ def run(
             description=description,
             tags=tags,
             op_spec=op_spec,
-            upload=upload,
             log=log,
-            can_upload=all([upload, project]),
         )
     else:
         platform_run(
@@ -232,8 +220,6 @@ def run(
             description=description,
             tags=tags,
             op_spec=op_spec,
-            upload=upload,
             log=log,
             watch=watch,
-            can_upload=all([upload, project]),
         )
