@@ -18,8 +18,8 @@ import os
 import sys
 import time
 
-from collections import Mapping
-from typing import Dict, Iterator, List, Sequence, Tuple, Union
+from collections.abc import Mapping
+from typing import Dict, List, Sequence, Union
 
 import click
 import polyaxon_sdk
@@ -31,6 +31,7 @@ from polyaxon import settings
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.client import PolyaxonClient
 from polyaxon.client.decorators import check_no_op, check_offline
+from polyaxon.containers.contexts import CONTEXT_MOUNT_ARTIFACTS
 from polyaxon.env_vars.getters import (
     get_project_full_name,
     get_project_or_local,
@@ -39,6 +40,7 @@ from polyaxon.env_vars.getters import (
 )
 from polyaxon.exceptions import PolyaxonClientException
 from polyaxon.lifecycle import LifeCycle, V1StatusCondition
+from polyaxon.logger import logger
 from polyaxon.polyaxonfile import check_polyaxonfile
 from polyaxon.polyboard.artifacts import V1ArtifactKind, V1RunArtifact
 from polyaxon.polyboard.logging.handler import get_logs_handler
@@ -47,7 +49,10 @@ from polyaxon.stores.polyaxon_store import PolyaxonStore
 from polyaxon.utils.code_reference import get_code_reference
 from polyaxon.utils.formatting import Printer
 from polyaxon.utils.hashing import hash_value
+from polyaxon.utils.http_utils import clean_host
+from polyaxon.utils.list_utils import to_list
 from polyaxon.utils.query_params import get_logs_params, get_query_params
+from polyaxon.utils.tz_utils import now
 from polyaxon.utils.validation import validate_tags
 
 
@@ -243,11 +248,11 @@ class RunClient:
         if you run a component/operation from the CLI/UI an instance will be created automatically.
 
         This is a generic create function, you can check other methods for creating runs:
-          * from yaml
-          * from hub
-          * from url
+          * from yaml: `create_from_polyaxonfile`
+          * from url: `create_from_url`
+          * from hub: `create_from_hub`
 
-        Note that if you don't pass data, the creation will pass,
+        > Note that if you don't pass `content`, the creation will pass,
         and the run will be marked as non-managed.
 
         [Run API](/docs/api/#operation/CreateRun)
@@ -285,6 +290,7 @@ class RunClient:
         )
         self._create(data=data, async_req=False)
         self._post_create()
+        return self.run_data
 
     @check_no_op
     @check_offline
@@ -417,8 +423,7 @@ class RunClient:
         N.B. Create methods are only useful if you want to create a run programmatically,
         if you run a component/operation from the CLI/UI an instance will be created automatically.
 
-        By default the hub hosts components. If the component has required inputs,
-        you should pass the params.
+        If the component has required inputs, you should pass the params.
 
         [Run API](/docs/api/#operation/CreateRun)
 
@@ -523,19 +528,59 @@ class RunClient:
         except (ApiException, HTTPError) as e:
             raise PolyaxonClientException("Api error: %s" % e) from e
 
+    def _wait_for_condition(self, statuses: List[str] = None):
+        statuses = to_list(statuses, check_none=True)
+
+        def condition():
+            if statuses:
+                return last_status in statuses
+            return LifeCycle.is_done(last_status)
+
+        last_status = None
+        while not condition():
+            if last_status:
+                time.sleep(settings.CLIENT_CONFIG.watch_interval)
+            last_status, _conditions = self.get_statuses(last_status)
+            yield last_status, _conditions
+
     @check_no_op
     @check_offline
-    def watch_statuses(self):
-        """Watches run statuses."""
+    def wait_for_condition(
+        self, statuses: List[str] = None, print_status: bool = False
+    ):
+        """Waits for the run's last status to meet a condition.
 
-        def watch_run_statuses() -> Tuple[str, Iterator]:
-            last_status = None
-            while not LifeCycle.is_done(last_status):
-                last_status, _conditions = self.get_statuses(last_status)
-                yield last_status, _conditions
-                time.sleep(settings.CLIENT_CONFIG.watch_interval)
+        If statuses is passed the it will wait for the condition:
+         * last status is one of the statuses passed.
 
-        for status, conditions in watch_run_statuses():
+        Otherwise, it will wait until the user interrupts the function or reaches a final status.
+
+        N.B. if you want to watch statuses and and receive the status/conditions,
+        please use `watch_statuses` instead which yields the results.
+        """
+        for status, conditions in self._wait_for_condition(statuses):
+            self._run_data.status = status
+            if print_status:
+                print("Last received status: {}\n".format(status))
+
+    @check_no_op
+    @check_offline
+    def watch_statuses(self, statuses: List[str] = None):
+        """Watches run statuses.
+
+        If statuses is passed the watch will wait for a condition:
+         * last status is one of the statuses passed.
+
+        Otherwise, it will watch until the user interrupts it or reaches a final status.
+
+        N.B. if you just wait for a status condition without expecting a yield,
+        please use `wait_for_condition` instead
+
+        Yields:
+            Tuple[status, List[conditions]]:
+                This function will yield the last status and condition for every check.
+        """
+        for status, conditions in self._wait_for_condition(statuses):
             self._run_data.status = status
             yield status, conditions
 
@@ -569,13 +614,20 @@ class RunClient:
 
     @check_no_op
     @check_offline
-    def get_events(self, kind: V1ArtifactKind, names: List[str], orient: str = None):
+    def get_events(
+        self,
+        kind: V1ArtifactKind,
+        names: List[str],
+        orient: str = None,
+        force: bool = False,
+    ):
         """Gets the run's events
 
         Args:
             kind: str, a valid `V1ArtifactKind`.
             names: List[str], list of events to return.
             orient: str, csv or dict.
+            force: bool, force reload the events.
         """
         return self.client.runs_v1.get_run_events(
             self.namespace,
@@ -585,6 +637,7 @@ class RunClient:
             kind=kind,
             names=names,
             orient=orient,
+            force=force,
         )
 
     @check_no_op
@@ -595,6 +648,7 @@ class RunClient:
         runs: List[str],
         names: List[str],
         orient: str = None,
+        force: bool = False,
     ):
         """Gets multi-runs events.
 
@@ -603,6 +657,7 @@ class RunClient:
             runs: List[str], list of run uuids to return events for.
             names: List[str], list of events to return.
             orient: str, csv or dict.
+            force: bool, force reload the events.
         """
         return self.client.runs_v1.get_multi_run_events(
             self.namespace,
@@ -612,16 +667,18 @@ class RunClient:
             names=names,
             runs=runs,
             orient=orient,
+            force=force,
         )
 
     @check_no_op
     @check_offline
-    def get_artifact(self, path: str, stream: bool = True):
+    def get_artifact(self, path: str, stream: bool = True, force: bool = False):
         """Gets the run's artifact.
 
         Args:
             path: str, the relative path of the artifact to return.
             stream: bool, optional, default: True, whether to stream the artifact content.
+            force: bool, force reload the artifact.
 
         Returns:
             str.
@@ -633,29 +690,33 @@ class RunClient:
             uuid=self.run_uuid,
             path=path,
             stream=stream,
+            force=force,
             _preload_content=True,
         )
 
     @check_no_op
     @check_offline
-    def download_artifact(self, path: str):
+    def download_artifact(self, path: str, force: bool = False):
         """Downloads run artifact.
 
         Args:
             path: str, the relative path of the artifact to return.
+            force: bool, force reload the artifact.
 
         Returns:
             str
         """
         url = "{host}/streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifact".format(
-            host=self.client.config.host,
+            host=clean_host(self.client.config.host),
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
             uuid=self.run_uuid,
         )
+        if force:
+            url = "{}?force=true".format(url)
 
-        return PolyaxonStore(client=self).download_file(url=url, path=path)
+        return PolyaxonStore(client=self).download_file(url=url, path=path, force=force)
 
     @check_no_op
     @check_offline
@@ -680,7 +741,7 @@ class RunClient:
             str.
         """
         url = "{host}/streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifacts".format(
-            host=self.client.config.host,
+            host=clean_host(self.client.config.host),
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
@@ -691,6 +752,7 @@ class RunClient:
             url=url,
             path=path,
             untar=untar,
+            path_to=path_to,
             delete_tar=delete_tar,
             extract_path=extract_path,
         )
@@ -954,12 +1016,13 @@ class RunClient:
 
     @check_no_op
     @check_offline
-    def log_code_ref(self, code_ref: Dict = None):
+    def log_code_ref(self, code_ref: Dict = None, is_input: bool = True):
         """Logs code reference.
 
         Args:
             code_ref: dict, optional, if not provided,
                 Polyaxon will detect the code reference from the git repo in the current path.
+            is_input: bool, if the code reference is an input or outputs.
         """
         code_ref = code_ref or get_code_reference()
         if code_ref and "commit" in code_ref:
@@ -967,13 +1030,32 @@ class RunClient:
                 name=code_ref.get("commit"),
                 kind=V1ArtifactKind.CODEREF,
                 summary=code_ref,
-                is_input=True,
+                is_input=is_input,
             )
             self.log_artifact_lineage(body=artifact_run)
 
+    @staticmethod
+    def get_rel_asset_path(path: str = None, rel_path: str = None):
+        if not path or rel_path:
+            return rel_path
+        if CONTEXT_MOUNT_ARTIFACTS in path:
+            try:
+                return os.path.relpath(path, CONTEXT_MOUNT_ARTIFACTS)
+            except Exception as e:
+                logger.debug("could not calculate relative path %s", e)
+
+        return rel_path or path
+
     @check_no_op
     @check_offline
-    def log_data_ref(self, name: str, hash: str = None, path: str = None, content=None):
+    def log_data_ref(
+        self,
+        name: str,
+        hash: str = None,
+        path: str = None,
+        content=None,
+        is_input: bool = True,
+    ):
         """Logs data reference.
 
         Args:
@@ -981,6 +1063,7 @@ class RunClient:
             hash: str, optional, default = None, the hash version of the data,
                 if not provided it will be calculated based on the data in the content.
             path: str, optional, path of where the data is coming from.
+            is_input: bool, if the data reference is an input or outputs.
             content: the data content.
         """
         summary = {}
@@ -992,13 +1075,25 @@ class RunClient:
             summary["path"] = path
         if name:
             artifact_run = V1RunArtifact(
-                name=name, kind=V1ArtifactKind.DATA, summary=summary, is_input=True,
+                name=name,
+                kind=V1ArtifactKind.DATA,
+                path=path,
+                summary=summary,
+                is_input=is_input,
             )
             self.log_artifact_lineage(body=artifact_run)
 
     @check_no_op
     @check_offline
-    def log_file_ref(self, path: str, name: str = None, hash: str = None, content=None):
+    def log_file_ref(
+        self,
+        path: str,
+        name: str = None,
+        hash: str = None,
+        content=None,
+        is_input: bool = False,
+        rel_path: str = None,
+    ):
         """Logs file reference.
 
         Args:
@@ -1007,6 +1102,8 @@ class RunClient:
             hash: str, optional, default = None, the hash version of the file,
                 if not provided it will be calculated based on the file content.
             content: the file content.
+            is_input: bool, if the file reference is an input or outputs.
+            rel_path: str, optional relative path to the run artifacts path.
         """
         summary = {"path": path}
         if hash:
@@ -1014,45 +1111,66 @@ class RunClient:
         elif content is not None:
             summary["hash"] = hash_value(content)
         name = name or os.path.basename(path)
+        rel_path = self.get_rel_asset_path(path=path, rel_path=rel_path)
         if name:
             artifact_run = V1RunArtifact(
-                name=name, kind=V1ArtifactKind.FILE, summary=summary, is_input=True,
+                name=name,
+                kind=V1ArtifactKind.FILE,
+                path=rel_path,
+                summary=summary,
+                is_input=is_input,
             )
             self.log_artifact_lineage(body=artifact_run)
 
     @check_no_op
     @check_offline
-    def log_dir_ref(self, path: str, name: str = None):
+    def log_dir_ref(
+        self, path: str, name: str = None, is_input: bool = False, rel_path: str = None,
+    ):
         """Logs dir reference.
 
         Args:
             path: str, dir path, the name is extracted from the path.
             name: str, if the name is passed it will be used instead of the dirname from the path.
+            is_input: bool, if the dir reference is an input or outputs.
+            rel_path: str, optional relative path to the run artifacts path.
         """
         name = name or os.path.basename(path)
+        rel_path = self.get_rel_asset_path(path=path, rel_path=rel_path)
         if name:
             artifact_run = V1RunArtifact(
                 name=name,
                 kind=V1ArtifactKind.DIR,
+                path=rel_path,
                 summary={"path": path},
-                is_input=True,
+                is_input=is_input,
             )
             self.log_artifact_lineage(body=artifact_run)
 
     @check_no_op
     @check_offline
-    def log_tensorboard_ref(self, path: str, name: str = "tensorboard"):
+    def log_tensorboard_ref(
+        self,
+        path: str,
+        name: str = "tensorboard",
+        is_input: bool = False,
+        rel_path: str = None,
+    ):
         """Logs dir reference.
 
         Args:
             path: str, path to the tensorboard logdir.
             name: str, if the name is passed it will be used instead of the dirname from the path.
+            is_input: bool, if the tensorboard reference is an input or outputs
+            rel_path: str, optional relative path to run the artifacts path.
         """
+        rel_path = self.get_rel_asset_path(path=path, rel_path=rel_path)
         artifact_run = V1RunArtifact(
             name=name,
             kind=V1ArtifactKind.TENSORBOARD,
+            path=rel_path,
             summary={"path": path},
-            is_input=True,
+            is_input=is_input,
         )
         self.log_artifact_lineage(body=artifact_run)
         self._log_meta(has_tensorboard=True)
@@ -1171,35 +1289,52 @@ def get_run_logs(
 
     def handle_logs():
         is_done = False
-        last_time = None
         last_file = None
         _status = None
-        last_status, _ = client.get_statuses()
+        files = []
+        last_transition_time = now()
+        last_status, conditions = client.get_statuses()
+        if conditions:
+            last_transition_time = conditions[0].last_transition_time
+
         while not LifeCycle.is_done(last_status) and not LifeCycle.is_running(
             last_status
         ):
-            time.sleep(1)
-            last_status, _ = client.get_statuses()
+            time.sleep(settings.CLIENT_CONFIG.watch_interval)
+            last_status, conditions = client.get_statuses()
+            if conditions:
+                last_transition_time = conditions[0].last_transition_time
             if _status != last_status:
                 _status = handle_status(last_status)
 
+        if LifeCycle.is_done(last_status):
+            last_time = None
+        else:
+            last_time = last_transition_time
+
+        checks = 0
         while not is_done:
             response = get_logs(last_time=last_time, last_file=last_file)
 
             if response:
                 last_time = response.last_time
                 last_file = response.last_file
+                files = response.files
             else:
                 last_time = None
                 last_file = None
 
             # Follow logic
-            if not any([last_file, last_time]):
+            if not any([last_file, last_time]) or checks > 3:
                 if follow:
                     last_status, _ = client.get_statuses()
                     if _status != last_status:
                         _status = handle_status(last_status)
                     is_done = LifeCycle.is_done(last_status)
+                    if not is_done:
+                        checks = 0
+                    if not last_time:
+                        last_time = last_transition_time
                 else:
                     is_done = True
             if last_time and not follow:
@@ -1207,8 +1342,12 @@ def get_run_logs(
 
             if not is_done:
                 if last_file:
-                    time.sleep(1)
+                    if len(files) > 1 and last_file != files[-1]:
+                        time.sleep(1)
+                    else:
+                        is_done = True
                 else:
                     time.sleep(settings.CLIENT_CONFIG.watch_interval)
+            checks += 1
 
     handle_logs()
