@@ -21,6 +21,7 @@ from polyaxon.deploy.schemas.deployment_types import DeploymentCharts, Deploymen
 from polyaxon.deploy.schemas.email import EmailSchema
 from polyaxon.deploy.schemas.ingress import IngressSchema
 from polyaxon.deploy.schemas.intervals import IntervalsSchema
+from polyaxon.deploy.schemas.operators import OperatorsSchema
 from polyaxon.deploy.schemas.rbac import RBACSchema
 from polyaxon.deploy.schemas.root_user import RootUserSchema
 from polyaxon.deploy.schemas.security_context import SecurityContextSchema
@@ -30,6 +31,7 @@ from polyaxon.deploy.schemas.service import (
     ExternalServicesSchema,
     HelperServiceSchema,
     HooksSchema,
+    OperatorServiceSchema,
     PostgresqlSchema,
     RabbitmqSchema,
     RedisSchema,
@@ -38,6 +40,7 @@ from polyaxon.deploy.schemas.service import (
 )
 from polyaxon.deploy.schemas.service_types import ServiceTypes
 from polyaxon.deploy.schemas.ssl import SSLSchema
+from polyaxon.deploy.schemas.ui import UISchema
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.types import ConnectionTypeSchema
 
@@ -173,6 +176,7 @@ class DeploymentSchema(BaseCamelSchema):
         default=DeploymentCharts.PLATFORM,
     )
     deployment_version = fields.Str(allow_none=True)
+    release_name = fields.Str(allow_none=True)
     namespace = fields.Str(allow_none=True)
     rbac = fields.Nested(RBACSchema, allow_none=True)
     polyaxon_secret = fields.Str(allow_none=True)
@@ -180,7 +184,8 @@ class DeploymentSchema(BaseCamelSchema):
     password_length = fields.Int(allow_none=True)
     ssl = fields.Nested(SSLSchema, allow_none=True)
     encryption_secret = fields.Str(allow_none=True)
-    admin_view_enabled = fields.Bool(allow_none=True)
+    platform_secret = fields.Str(allow_none=True)
+    agent_secret = fields.Str(allow_none=True)
     timezone = fields.Str(allow_none=True)
     environment = fields.Str(allow_none=True)
     ingress = fields.Nested(IngressSchema, allow_none=True)
@@ -198,10 +203,11 @@ class DeploymentSchema(BaseCamelSchema):
     worker = fields.Nested(WorkerServiceSchema, allow_none=True)
     beat = fields.Nested(ServiceSchema, allow_none=True)
     agent = fields.Nested(AgentServiceSchema, allow_none=True)
-    operator = fields.Nested(ServiceSchema, allow_none=True)
+    operator = fields.Nested(OperatorServiceSchema, allow_none=True)
     init = fields.Nested(HelperServiceSchema, allow_none=True)
     sidecar = fields.Nested(HelperServiceSchema, allow_none=True)
     tables_hook = fields.Nested(ServiceSchema, allow_none=True)
+    clean_hooks = fields.Nested(ServiceSchema, allow_none=True)
     hooks = fields.Nested(HooksSchema, allow_none=True)
     postgresql = fields.Nested(PostgresqlSchema, allow_none=True)
     redis = fields.Nested(RedisSchema, allow_none=True)
@@ -220,15 +226,15 @@ class DeploymentSchema(BaseCamelSchema):
         fields.Nested(ConnectionTypeSchema), allow_none=True,
     )
     log_level = fields.Str(allow_none=True)
-    tracker_backend = fields.Str(allow_none=True)
     security_context = fields.Nested(SecurityContextSchema, allow_none=True)
     external_services = fields.Nested(ExternalServicesSchema, allow_none=True)
     debug_mode = fields.Bool(allow_none=True)
     organization_key = fields.Str(allow_none=True)
     auth = fields.Nested(AuthSchema, allow_none=True)
-    js_offline = fields.Bool(allow_none=True)
-    ui_enabled = fields.Bool(allow_none=True)
-
+    ui = fields.Nested(UISchema, allow_none=True)
+    include_chart_revision = fields.Bool(allow_none=True)
+    operators = fields.Nested(OperatorsSchema, allow_none=True)
+    istio = fields.Dict(allow_none=True)
     # Pending validation
     dns = fields.Raw(allow_none=True)
 
@@ -259,7 +265,6 @@ class DeploymentSchema(BaseCamelSchema):
                 polyaxon_secret=data.get("polyaxon_secret"),
                 internal_token=data.get("internal_token"),
                 password_length=data.get("password_length"),
-                admin_view_enabled=data.get("admin_view_enabled"),
                 user=data.get("user"),
                 global_replicas=data.get("global_replicas"),
                 global_concurrency=data.get("global_concurrency"),
@@ -278,6 +283,7 @@ class DeploymentSchema(BaseCamelSchema):
                 intervals=data.get("intervals"),
                 metrics=data.get("metrics"),
                 organization_key=data.get("organization_key"),
+                ui=data.get("ui"),
             )
 
 
@@ -289,6 +295,7 @@ class DeploymentConfig(BaseConfig):
         deployment_type=None,
         deployment_chart=None,
         deployment_version=None,
+        release_name=None,
         namespace=None,
         rbac=None,
         polyaxon_secret=None,
@@ -296,7 +303,8 @@ class DeploymentConfig(BaseConfig):
         password_length=None,
         ssl=None,
         encryption_secret=None,
-        admin_view_enabled=None,
+        platform_secret=None,
+        agent_secret=None,
         timezone=None,
         environment=None,
         ingress=None,
@@ -318,6 +326,7 @@ class DeploymentConfig(BaseConfig):
         init=None,
         sidecar=None,
         tables_hook=None,
+        clean_hooks=None,
         hooks=None,
         postgresql=None,
         redis=None,
@@ -334,15 +343,16 @@ class DeploymentConfig(BaseConfig):
         connections=None,
         notification_connections=None,
         log_level=None,
-        tracker_backend=None,
         security_context=None,
         external_services=None,
         debug_mode=None,
         auth=None,
         organization_key=None,
         dns=None,
-        js_offline=None,
-        ui_enabled=None,
+        ui=None,
+        operators=None,
+        istio=None,
+        include_chart_revision=None,
     ):
         validate_deployment_chart(
             deployment_chart=deployment_chart, agent=agent, environment=environment,
@@ -361,6 +371,7 @@ class DeploymentConfig(BaseConfig):
         self.deployment_type = deployment_type
         self.deployment_chart = deployment_chart or DeploymentCharts.PLATFORM
         self.deployment_version = deployment_version
+        self.release_name = release_name
         self.namespace = namespace
         self.rbac = rbac
         self.polyaxon_secret = polyaxon_secret
@@ -369,7 +380,8 @@ class DeploymentConfig(BaseConfig):
         self.ssl = ssl
         self.dns = dns
         self.encryption_secret = encryption_secret
-        self.admin_view_enabled = admin_view_enabled
+        self.platform_secret = platform_secret
+        self.agent_secret = agent_secret
         self.timezone = timezone
         self.environment = environment
         self.ingress = ingress
@@ -391,6 +403,7 @@ class DeploymentConfig(BaseConfig):
         self.init = init
         self.sidecar = sidecar
         self.tables_hook = tables_hook
+        self.clean_hooks = clean_hooks
         self.hooks = hooks
         self.postgresql = postgresql
         self.redis = redis
@@ -407,20 +420,22 @@ class DeploymentConfig(BaseConfig):
         self.connections = connections
         self.notification_connections = notification_connections
         self.log_level = log_level
-        self.tracker_backend = tracker_backend
         self.security_context = security_context
         self.external_services = external_services
         self.debug_mode = debug_mode
         self.auth = auth
         self.organization_key = organization_key
-        self.js_offline = js_offline
-        self.ui_enabled = ui_enabled
+        self.ui = ui
+        self.operators = operators
+        self.istio = istio
+        self.include_chart_revision = include_chart_revision
         if self.deployment_chart == DeploymentCharts.AGENT:
             wrong_agent_deployment_keys(
                 polyaxon_secret=polyaxon_secret,
                 internal_token=internal_token,
                 password_length=password_length,
-                admin_view_enabled=admin_view_enabled,
+                platform_secret=platform_secret,
+                encryption_secret=encryption_secret,
                 user=user,
                 global_replicas=global_replicas,
                 global_concurrency=global_concurrency,
@@ -439,4 +454,5 @@ class DeploymentConfig(BaseConfig):
                 intervals=intervals,
                 metrics=metrics,
                 organization_key=organization_key,
+                ui=ui,
             )
