@@ -25,10 +25,10 @@ def get_container_statuses_by_name(statuses):
     }
 
 
-def get_container_status(statuses, job_container_names):
+def get_container_status(statuses, container_ids):
     job_container_status = None
-    for job_container_name in job_container_names:
-        job_container_status = statuses.get(job_container_name)
+    for container_id in container_ids:
+        job_container_status = statuses.get(container_id)
         if job_container_status:
             break
     return job_container_status
