@@ -19,8 +19,6 @@ import os
 import click
 import click_completion
 
-from marshmallow import ValidationError
-
 from polyaxon import settings
 from polyaxon.cli.admin import admin
 from polyaxon.cli.auth import login, logout, whoami
@@ -28,15 +26,16 @@ from polyaxon.cli.check import check
 from polyaxon.cli.completion import completion
 from polyaxon.cli.config import config
 from polyaxon.cli.dashboard import dashboard
+from polyaxon.cli.hub import hub
 from polyaxon.cli.init import init
 from polyaxon.cli.operations import ops
 from polyaxon.cli.port_forward import port_forward
 from polyaxon.cli.projects import project
 from polyaxon.cli.run import run
+from polyaxon.cli.session import set_versions_config
 from polyaxon.cli.upload import upload
 from polyaxon.cli.version import check_cli_version, upgrade, version
-from polyaxon.logger import clean_outputs, configure_logger
-from polyaxon.managers.client import ClientConfigManager
+from polyaxon.logger import configure_logger
 from polyaxon.utils.bool_utils import to_bool
 
 DOCS_GEN = to_bool(os.environ.get("POLYAXON_DOCS_GEN", False))
@@ -48,9 +47,6 @@ click_completion.init()
 @click.option(
     "-v", "--verbose", is_flag=True, default=False, help="Turn on debug logging"
 )
-@click.option(
-    "-c", "--check", is_flag=True, default=False, help="Turn on version check"
-)
 @click.option(
     "--offline",
     is_flag=True,
@@ -59,23 +55,59 @@ click_completion.init()
     "Currently used for run command in --local mode.",
 )
 @click.pass_context
-@clean_outputs
-def cli(context, verbose, check, offline):
-    """ Polyaxon CLI tool to:
+def cli(context, verbose, offline):
+    """Polyaxon - Cloud Native Machine Learning Automation & Experimentation tool.
 
-        * Parse, Validate, and Check Polyaxonfiles.
+    This CLI provides tools to:
 
-        * Interact with Polyaxon server.
+      - Parse, Validate, and Check Polyaxonfiles.
 
-        * Run and Monitor experiments.
+      - Interact with Polyaxon server.
+
+      - Run and Monitor experiments and jobs.
+
+    This CLI tool comes with a caching mechanism:
+
+      - You can initialize a project with: polyaxon init [project name]
+
+      - Otherwise Polyaxon will the default global path will be used for the cache.
+
+    You can check the version of you CLI by running:
+
+      - polyaxon version
+
+    To Enable debug mode, you can use the `-v` flag:
+
+      - polyaxon -v admin
+
+    Common commands:
+
+      - polyaxon project get
+
+      - polyaxon run [-f] [-l]
+
+      - polyaxon ops ls
+
+      - polyaxon ops get
+
+      - polyaxon config -l
+
+      - polyaxon config set ...
+
+    Admin deployment commands:
+
+      - polyaxon admin deploy [-f] [--check]
+
+      - polyaxon admin upgrade [-f] [--check]
+
+      - polyaxon admin teardown [-f]
+
+    For more information, please visit https://polyaxon.com/docs/core/cli/
 
     Check the help available for each command listed below.
     """
-
-    try:
-        configure_logger(verbose or ClientConfigManager.get_value("debug"))
-    except ValidationError:
-        ClientConfigManager.purge()
+    settings.set_cli_config()
+    configure_logger(verbose)
     non_check_cmds = [
         "completion",
         "config",
@@ -90,6 +122,8 @@ def cli(context, verbose, check, offline):
         "sidecar",
         "proxy",
         "notify",
+        "upgrade",
+        "port-forward",
     ]
     context.obj = context.obj or {}
     if not settings.CLIENT_CONFIG.client_header:
@@ -98,14 +132,17 @@ def cli(context, verbose, check, offline):
     if offline:
         os.environ["POLYAXON_IS_OFFLINE"] = "true"
         settings.CLIENT_CONFIG.is_offline = True
-    if check and not (
+    if not (
         context.invoked_subcommand in non_check_cmds
         or offline
         or settings.CLIENT_CONFIG.no_api
         or settings.CLIENT_CONFIG.is_ops
         or DOCS_GEN
+    ) and settings.CLI_CONFIG.should_check(
+        settings.CLIENT_CONFIG.compatibility_check_interval
     ):
-        check_cli_version()
+        cli_config = set_versions_config()
+        check_cli_version(cli_config)
 
 
 cli.add_command(login)
@@ -118,15 +155,17 @@ cli.add_command(check)
 cli.add_command(init)
 cli.add_command(project)
 cli.add_command(ops)
-cli.add_command(upload)
+cli.add_command(hub)
 cli.add_command(run)
 cli.add_command(dashboard)
 cli.add_command(admin)
 cli.add_command(port_forward)
 cli.add_command(completion)
+cli.add_command(upload)
 if settings.CLIENT_CONFIG.is_ops:
 
     from polyaxon.cli.components.agent import agent
+    from polyaxon.cli.components.clean_ops import clean_ops
     from polyaxon.cli.components.docker import docker
     from polyaxon.cli.components.initializer import initializer
     from polyaxon.cli.components.notifier import notify
@@ -135,9 +174,10 @@ if settings.CLIENT_CONFIG.is_ops:
     from polyaxon.cli.components.tuner import tuner
 
     cli.add_command(agent)
+    cli.add_command(clean_ops)
     cli.add_command(docker)
     cli.add_command(initializer)
-    cli.add_command(sidecar)
-    cli.add_command(proxy)
     cli.add_command(notify)
+    cli.add_command(proxy)
+    cli.add_command(sidecar)
     cli.add_command(tuner)
