@@ -17,7 +17,7 @@
 import json
 import re
 
-from collections import Mapping
+from collections.abc import Mapping
 from datetime import date, datetime
 from distutils.util import strtobool  # pylint:disable=import-error
 from json import JSONDecodeError
@@ -926,15 +926,27 @@ def _get_typed_list_value(
         base_types: the base types to check for conversion
     """
 
-    value = _get_typed_value(
-        key=key,
-        value=value,
-        target_type=list,
-        type_convert=json.loads,
-        is_optional=is_optional,
-        default=default,
-        options=options,
-    )
+    try:
+        value = _get_typed_value(
+            key=key,
+            value=value,
+            target_type=list,
+            type_convert=json.loads,
+            is_optional=is_optional,
+            default=default,
+            options=options,
+        )
+    except PolyaxonSchemaError as e:
+        # We try to parsing a list from a string
+        value = get_list(
+            key=key,
+            value=value,
+            is_optional=is_optional,
+            default=default,
+            options=options,
+        )
+        if len(value) <= 1:
+            raise e
 
     if not value:
         return default
