@@ -18,11 +18,12 @@ import ast
 import copy
 import jinja2
 
-from collections import Mapping
+from collections.abc import Mapping
 from typing import Dict
 
 from polyaxon.config_reader.utils import deep_update
 from polyaxon.exceptions import PolyaxonSchemaError
+from polyaxon.polyaxonfile.specs.libs.engine import get_engine
 from polyaxon.polyaxonfile.specs.sections import Sections
 from polyaxon.polyflow import ParamSpec
 
@@ -32,10 +33,10 @@ except (ImportError, ModuleNotFoundError):
     np = None
 
 
-class Parser(object):
+class Parser:
     """Parses the Polyaxonfile."""
 
-    env = jinja2.Environment()
+    engine = get_engine()
 
     @staticmethod
     def _get_section_data(section_data):
@@ -55,10 +56,10 @@ class Parser(object):
 
     @classmethod
     def parse(
-        cls, config, params: Dict[str, ParamSpec]
+        cls, config, param_spec: Dict[str, ParamSpec]
     ):  # pylint:disable=too-many-branches
-        params = params or {}
-        parsed_params = {param: params[param].display_value for param in params}
+        param_spec = param_spec or {}
+        parsed_params = {param: param_spec[param].display_value for param in param_spec}
 
         parsed_data = {Sections.VERSION: config.version, Sections.KIND: config.kind}
 
@@ -108,23 +109,42 @@ class Parser(object):
         return parsed_data
 
     @classmethod
-    def parse_run(cls, parsed_data, params: Dict[str, ParamSpec]):
+    def parse_runtime(cls, parsed_data, param_spec: Dict[str, ParamSpec]):
         config_section = cls.parse_section(
-            parsed_data.get(Sections.RUN), params=params, parse_params=True
+            parsed_data.get(Sections.RUN), param_spec=param_spec, parse_params=True
         )
         if config_section:
             parsed_data[Sections.RUN] = config_section
         return parsed_data
 
     @classmethod
-    def parse_section(
-        cls, config_section, params: Dict[str, ParamSpec], parse_params: bool = True
+    def parse_distributed_runtime(
+        cls, parsed_data, param_spec: Dict[str, Dict[str, ParamSpec]]
     ):
-        params = params or {}
-        if parse_params:
-            params = {param: params[param].display_value for param in params}
+        run_section = parsed_data.get(Sections.RUN)
+        config_section = {}
+        for k in run_section:
+            if k in param_spec:
+                config_section[k] = cls.parse_section(
+                    run_section[k], param_spec=param_spec[k], parse_params=True
+                )
+            else:
+                config_section[k] = run_section[k]
         if config_section:
-            return cls.parse_expression(config_section, params)
+            parsed_data[Sections.RUN] = config_section
+        return parsed_data
+
+    @classmethod
+    def parse_section(
+        cls, config_section, param_spec: Dict[str, ParamSpec], parse_params: bool = True
+    ):
+        param_spec = param_spec or {}
+        if parse_params:
+            param_spec = {
+                param: param_spec[param].display_value for param in param_spec
+            }
+        if config_section:
+            return cls.parse_expression(config_section, param_spec)
         return config_section
 
     @classmethod
@@ -179,7 +199,7 @@ class Parser(object):
 
     @classmethod
     def _evaluate_expression(cls, expression, params, check_operators):
-        result = cls.env.from_string(expression).render(**params)
+        result = cls.engine.from_string(expression).render(**params)
         if result == expression:
             try:
                 return ast.literal_eval(result)
