@@ -16,13 +16,6 @@
 
 from polyaxon.polyflow.cache import CacheSchema, V1Cache
 from polyaxon.polyflow.component import ComponentSchema, V1Component
-from polyaxon.polyflow.conditions import (
-    ConditionSchema,
-    IoCondSchema,
-    StatusCondSchema,
-    V1IoCond,
-    V1StatusCond,
-)
 from polyaxon.polyflow.dags import DagOpSpec
 from polyaxon.polyflow.early_stopping import (
     DiffStoppingPolicySchema,
@@ -55,14 +48,14 @@ from polyaxon.polyflow.operations import (
 )
 from polyaxon.polyflow.operators import ForConfig, IfConfig
 from polyaxon.polyflow.optimization import (
-    Optimization,
+    V1Optimization,
     OptimizationMetricSchema,
     OptimizationResourceSchema,
     ResourceType,
     V1OptimizationMetric,
     V1OptimizationResource,
 )
-from polyaxon.polyflow.parallel import (
+from polyaxon.polyflow.matrix import (
     AcquisitionFunctions,
     BayesSchema,
     GaussianProcessConfig,
@@ -72,8 +65,8 @@ from polyaxon.polyflow.parallel import (
     HyperoptSchema,
     IterativeSchema,
     MappingSchema,
-    ParallelMixin,
-    ParallelSchema,
+    MatrixMixin,
+    MatrixSchema,
     RandomSearchSchema,
     UtilityFunctionConfig,
     V1Bayes,
@@ -83,7 +76,8 @@ from polyaxon.polyflow.parallel import (
     V1Iterative,
     V1Mapping,
     V1RandomSearch,
-    V1ParallelKind,
+    V1Matrix,
+    V1MatrixKind,
     V1HpChoice,
     V1HpGeomSpace,
     V1HpLinSpace,
@@ -108,15 +102,15 @@ from polyaxon.polyflow.params import (
 )
 from polyaxon.polyflow.plugins import PluginsSchema, V1Plugins
 from polyaxon.polyflow.references import (
-    DagReferenceSchema,
-    HubReferenceSchema,
-    PathReferenceSchema,
+    DagRefSchema,
+    HubRefSchema,
+    PathRefSchema,
     RefMixin,
-    UrlReferenceSchema,
-    V1DagReference,
-    V1HubReference,
-    V1PathReference,
-    V1UrlReference,
+    UrlRefSchema,
+    V1DagRef,
+    V1HubRef,
+    V1PathRef,
+    V1UrlRef,
 )
 from polyaxon.polyflow.run import (
     DagSchema,
@@ -125,6 +119,7 @@ from polyaxon.polyflow.run import (
     JobSchema,
     KFReplicaSchema,
     MPIJobSchema,
+    NotifierSchema,
     PytorchJobSchema,
     RunMixin,
     RunSchema,
@@ -132,6 +127,8 @@ from polyaxon.polyflow.run import (
     SparkReplicaSchema,
     SparkSchema,
     TFJobSchema,
+    TunerSchema,
+    validate_run_patch,
     V1CleanPodPolicy,
     V1CloningKind,
     V1Dag,
@@ -140,6 +137,7 @@ from polyaxon.polyflow.run import (
     V1Job,
     V1KFReplica,
     V1MPIJob,
+    V1Notifier,
     V1PipelineKind,
     V1PytorchJob,
     V1RunKind,
@@ -149,6 +147,7 @@ from polyaxon.polyflow.run import (
     V1SparkReplica,
     V1SparkType,
     V1TFJob,
+    V1Tuner,
 )
 from polyaxon.polyflow.schedule import (
     CronScheduleSchema,
