@@ -18,8 +18,9 @@ import polyaxon_sdk
 
 from marshmallow import fields
 
-from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.types.base import BaseTypeConfig
 
 
 class ArtifactsTypeSchema(BaseCamelSchema):
@@ -34,7 +35,7 @@ class ArtifactsTypeSchema(BaseCamelSchema):
         return V1ArtifactsType
 
 
-class V1ArtifactsType(BaseConfig, polyaxon_sdk.V1ArtifactsType):
+class V1ArtifactsType(BaseTypeConfig, polyaxon_sdk.V1ArtifactsType):
     """Artifacts type allows to easily pass
     the files and directories to initialize as a single parameter.
 
@@ -49,7 +50,7 @@ class V1ArtifactsType(BaseConfig, polyaxon_sdk.V1ArtifactsType):
         files: List[str], optional, list of file subpaths
         dirs: List[str], optional, list of directory subpaths
         init: bool, optional, if True the files and the dirs will be automatically
-              downloaded / provided in the run's artifacts context.
+              downloaded/provided in the run's artifacts context.
         workers: int, optional, number of threads for downloading data from S3/GCS/Azure.
 
     ### YAML usage
@@ -75,7 +76,8 @@ class V1ArtifactsType(BaseConfig, polyaxon_sdk.V1ArtifactsType):
     >>>   dataset1: {value: {connection: "s3-dataset", init: True}}
     ```
 
-    The first param will be just a list of files definition that the user should know how to handle in their program.
+    The first param will be just a list of files definition that
+    the user should know how to handle in their program.
 
     The second param, Polyaxon will load only that directory path from connection "foo".
     This connection could be any bycket or volume.
