@@ -16,6 +16,7 @@
 from tests.utils import BaseTestCase
 
 from polyaxon import settings
+from polyaxon.auxiliaries import V1PolyaxonInitContainer, V1PolyaxonSidecarContainer
 from polyaxon.connections.kinds import V1ConnectionKind
 from polyaxon.connections.schemas import (
     V1BucketConnection,
@@ -23,10 +24,6 @@ from polyaxon.connections.schemas import (
     V1GitConnection,
     V1K8sResourceSchema,
 )
-from polyaxon.containers.containers import (
-    V1PolyaxonInitContainer,
-    V1PolyaxonSidecarContainer,
-)
 from polyaxon.k8s import k8s_schemas
 from polyaxon.polyflow import V1Init, V1Plugins
 from polyaxon.polypod.common.mounts import get_mounts
@@ -272,6 +269,7 @@ class TestJobConverter(BaseTestCase):
                 env=self.converter.get_init_service_env_vars(),
                 contexts=None,
                 run_path=self.converter.run_path,
+                run_instance=self.converter.run_instance,
             ),
             get_dockerfile_init_container(
                 dockerfile_args=dockerfile_args2,
@@ -280,6 +278,7 @@ class TestJobConverter(BaseTestCase):
                 mount_path="/test",
                 contexts=None,
                 run_path=self.converter.run_path,
+                run_instance=self.converter.run_instance,
             ),
         ]
         for container in expected_containers:
