@@ -18,6 +18,7 @@ import pytest
 
 from tests.utils import BaseTestCase
 
+from polyaxon.auxiliaries import V1PolyaxonSidecarContainer, get_sidecar_resources
 from polyaxon.connections.kinds import V1ConnectionKind
 from polyaxon.connections.schemas import (
     V1BucketConnection,
@@ -25,10 +26,7 @@ from polyaxon.connections.schemas import (
     V1HostPathConnection,
     V1K8sResourceSchema,
 )
-from polyaxon.containers.containers import (
-    V1PolyaxonSidecarContainer,
-    get_sidecar_resources,
-)
+from polyaxon.containers.names import MAIN_JOB_CONTAINER
 from polyaxon.exceptions import PolypodException
 from polyaxon.polyflow import V1Plugins
 from polyaxon.polypod.common.env_vars import (
@@ -43,7 +41,6 @@ from polyaxon.polypod.common.mounts import (
     get_mount_from_resource,
     get_mount_from_store,
 )
-from polyaxon.polypod.main.container import MAIN_JOB_CONTAINER
 from polyaxon.polypod.sidecar.container import (
     SIDECAR_CONTAINER,
     get_sidecar_args,
@@ -59,6 +56,7 @@ class TestSidecarContainer(BaseTestCase):
     def assert_artifacts_store_raises(self, store, run_path=None):
         with self.assertRaises(PolypodException):
             get_sidecar_container(
+                container_id=MAIN_JOB_CONTAINER,
                 contexts=PluginsContextsSpec.from_config(
                     V1Plugins(collect_logs=True, collect_artifacts=False)
                 ),
@@ -90,6 +88,7 @@ class TestSidecarContainer(BaseTestCase):
 
     def test_get_sidecar_container_without_an_artifacts_store(self):
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=None,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -116,6 +115,7 @@ class TestSidecarContainer(BaseTestCase):
             ),
         )
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -143,6 +143,7 @@ class TestSidecarContainer(BaseTestCase):
             schema=V1BucketConnection(bucket="s3//:foo"),
         )
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -178,6 +179,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # Default auth is included
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -194,7 +196,7 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
+        assert sidecar.command == ["polyaxon", "sidecar"]
         assert sidecar.volume_mounts == [
             get_auth_context_mount(read_only=True),
             get_artifacts_context_mount(read_only=False),
@@ -202,6 +204,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # Nno auth
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -218,7 +221,7 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
+        assert sidecar.command == ["polyaxon", "sidecar"]
         assert sidecar.volume_mounts == [get_artifacts_context_mount(read_only=False)]
 
     def test_get_sidecar_container_with_managed_bucket_outputs_logs_store_and_env_secret(
@@ -242,6 +245,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # Both logs/outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -258,15 +262,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -280,6 +285,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # logs and no outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -298,15 +304,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=-212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=-212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -319,6 +326,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # outputs and no logs
         sidecar = get_sidecar_container(
+            container_id="test",
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -337,15 +345,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id="test",
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id="test",
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -380,6 +389,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # Both logs and outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -396,15 +406,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -419,6 +430,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # logs and no outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -437,15 +449,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -459,6 +472,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # outputs and no logs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -477,15 +491,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -517,6 +532,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # both logs and outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -533,15 +549,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -555,6 +572,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # logs and no outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -573,15 +591,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -594,6 +613,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # outputs and no logs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -612,15 +632,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=bucket_managed_store.name,
         ) + get_items_from_secret(secret=resource1) + get_connection_env_var(
             connection=bucket_managed_store, secret=resource1
@@ -646,6 +667,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # logs and outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -662,15 +684,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=mount_managed_store.name,
         ) + get_connection_env_var(connection=mount_managed_store, secret=None)
         assert sidecar.env_from == []
@@ -683,6 +706,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # logs and no outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -701,15 +725,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=mount_managed_store.name,
         ) + get_connection_env_var(connection=mount_managed_store, secret=None)
         assert sidecar.env_from == []
@@ -721,6 +746,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # outputs and no logs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -739,15 +765,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=mount_managed_store.name,
         ) + get_connection_env_var(connection=mount_managed_store, secret=None)
         assert sidecar.env_from == []
@@ -775,6 +802,7 @@ class TestSidecarContainer(BaseTestCase):
 
         # logs and outputs
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             env=env_vars,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="sidecar/sidecar",
@@ -791,15 +819,16 @@ class TestSidecarContainer(BaseTestCase):
         assert sidecar.name == SIDECAR_CONTAINER
         assert sidecar.image == "sidecar/sidecar"
         assert sidecar.image_pull_policy == "IfNotPresent"
-        assert sidecar.command == ["/bin/bash", "-c"]
-        assert sidecar.args == [
-            get_sidecar_args(
-                container_id=MAIN_JOB_CONTAINER, sleep_interval=213, sync_interval=212
-            )
-        ]
+        assert sidecar.command == ["polyaxon", "sidecar"]
+        assert sidecar.args == get_sidecar_args(
+            container_id=MAIN_JOB_CONTAINER,
+            sleep_interval=213,
+            sync_interval=212,
+            monitor_logs=False,
+        )
         assert sidecar.env == get_sidecar_env_vars(
             env_vars=env_vars,
-            job_container_name=MAIN_JOB_CONTAINER,
+            container_id=MAIN_JOB_CONTAINER,
             artifacts_store_name=blob_managed_store.name,
         ) + get_connection_env_var(connection=blob_managed_store, secret=resource1)
         assert sidecar.env_from == [get_env_from_secret(secret=resource1)]
@@ -830,6 +859,7 @@ class TestSidecarContainer(BaseTestCase):
         )
 
         sidecar = get_sidecar_container(
+            container_id=MAIN_JOB_CONTAINER,
             polyaxon_sidecar=V1PolyaxonSidecarContainer(
                 image="foo",
                 image_pull_policy="sdf",
