@@ -18,7 +18,7 @@ import pytest
 
 from tests.utils import BaseTestCase
 
-from polyaxon.containers.containers import get_sidecar_resources
+from polyaxon.auxiliaries import get_sidecar_resources
 from polyaxon.env_vars.keys import (
     POLYAXON_KEYS_ARTIFACTS_STORE_NAME,
     POLYAXON_KEYS_CONTAINER_ID,
@@ -33,7 +33,7 @@ from polyaxon.polypod.sidecar.env_vars import get_sidecar_env_vars
 class TestSidecarUtils(BaseTestCase):
     def test_get_sidecar_env_vars(self):
         sidecar_env_vars = get_sidecar_env_vars(
-            env_vars=None, job_container_name="foo", artifacts_store_name="name"
+            env_vars=None, container_id="foo", artifacts_store_name="name"
         )
 
         assert sidecar_env_vars == [
@@ -47,7 +47,7 @@ class TestSidecarUtils(BaseTestCase):
             get_env_var(name="key2", value="value2"),
         ]
         sidecar_env_vars = get_sidecar_env_vars(
-            env_vars=env_vars, job_container_name="foo", artifacts_store_name="name"
+            env_vars=env_vars, container_id="foo", artifacts_store_name="name"
         )
 
         assert sidecar_env_vars == env_vars + [
@@ -57,7 +57,7 @@ class TestSidecarUtils(BaseTestCase):
 
         # Outputs Path
         sidecar_env_vars = get_sidecar_env_vars(
-            env_vars=None, job_container_name="foo", artifacts_store_name="name"
+            env_vars=None, container_id="foo", artifacts_store_name="name"
         )
 
         assert sidecar_env_vars == [
@@ -73,10 +73,16 @@ class TestSidecarUtils(BaseTestCase):
 
     def test_get_sidecar_args(self):
         assert get_sidecar_args(
-            container_id="job.2", sleep_interval=23, sync_interval=2
-        ) == (
-            "polyaxon sidecar "
-            "--container_id=job.2 "
-            "--sleep_interval=23 "
-            "--sync_interval=2"
-        )
+            container_id="job.2", sleep_interval=23, sync_interval=2, monitor_logs=None
+        ) == ["--container-id=job.2", "--sleep-interval=23", "--sync-interval=2"]
+        assert get_sidecar_args(
+            container_id="job.2", sleep_interval=23, sync_interval=2, monitor_logs=False
+        ) == ["--container-id=job.2", "--sleep-interval=23", "--sync-interval=2"]
+        assert get_sidecar_args(
+            container_id="job.2", sleep_interval=23, sync_interval=2, monitor_logs=True
+        ) == [
+            "--container-id=job.2",
+            "--sleep-interval=23",
+            "--sync-interval=2",
+            "--monitor-logs",
+        ]
